@@ -16,5 +16,8 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
+drop_relation_definition('GenomicMeasure', 'results_file', 'File')
+remove_cube('file')
 
-sync_schema_props_perms(('Snp', 'gene', 'Gene'))
+drop_attribute('GenomicMeasure', 'identifier')
+rename_attribute('GenomicPlatform', 'identifier', 'name')
