@@ -104,6 +104,8 @@ class GenomicRegion(EntityType):
     oncogenes = SubjectRelation('Gene', cardinality='**')
     atlas_genes = SubjectRelation('Gene', cardinality='**')
     census_genes = SubjectRelation('Gene', cardinality='**')
+    left_gene = SubjectRelation('Gene', cardinality='?*', inlined=True)
+    right_gene = SubjectRelation('Gene', cardinality='?*', inlined=True)
 
 
 class Snp(EntityType):
@@ -121,10 +123,11 @@ class GenomicMeasure(EntityType):
     """ A genomic measure """
     type = String(maxsize=256, required=True, indexed=True)
     format = String(maxsize=128, indexed=True)
-    chip_serialnum = Int()
     completed = Boolean(indexed=True)
     valid = Boolean(indexed=True)
-    platform = SubjectRelation('GenomicPlatform', cardinality='?*', inlined=True)
+    chip = SubjectRelation('Chip', cardinality='?*', inlined=True)
+    column_on_chip = Int()
+    row_on_chip = Int()
 
 
 class GenomicPlatform(EntityType):
@@ -132,6 +135,11 @@ class GenomicPlatform(EntityType):
     related_snps = SubjectRelation('Snp', cardinality='**')
 
 
+class Chip(EntityType):
+    barcode = Int(required=True, unique=True)
+    platform = SubjectRelation('GenomicPlatform', cardinality='1*', inlined=True)
+
+
 class ColumnRef(EntityType):
     """ Type is channel for transcriptom measure, lane for NGS measure.
         When type is channel, name will be red or green
